@@ -26,6 +26,8 @@ class SequenceResidue:
 class AtomLabel:
     residue: SequenceResidue
     atom_name: str
+    element: str = None
+    isotope_number: int = None
 
 
 @dataclass
@@ -134,8 +136,8 @@ class LineInfo:
 @dataclass
 class ShiftData:
     atom: AtomLabel
-    shift: float
-    error: Optional[float] = None
+    value: float
+    value_uncertainty: Optional[float] = None
 
 
 @dataclass
@@ -147,6 +149,6 @@ class ShiftList:
 class RdcRestraint:
     atom_1: AtomLabel
     atom_2: AtomLabel
-    rdc: float
-    rdc_error: float
+    value: float
+    value_uncertainty: float
     weight: Optional[float] = None
