@@ -1,4 +1,3 @@
-# import functools
 from textwrap import dedent
 from typing import Dict, Iterable, List, Tuple
 
@@ -16,6 +15,7 @@ from pyparsing import (
 )
 
 from nef_pipelines.lib.nef_lib import UNUSED
+from nef_pipelines.lib.sequence_lib import get_residue_name_from_lookup
 from nef_pipelines.lib.structures import (
     AtomLabel,
     SequenceResidue,
@@ -250,13 +250,13 @@ def parse_shifts(
                                         i got{num_atom_fields} at line {i + 1}
                                         with data: {line}"""
             exit_error(msg)
-        residue_number, atom = atom_fields
+        residue_code, atom = atom_fields
 
         try:
-            residue_number = int(residue_number)
+            residue_code = int(residue_code)
         except ValueError:
             msg = f"""An nmrview residue number should be an integer
-                      i got {residue_number} at line {i + 1}"""
+                      i got {residue_code} at line {i + 1}"""
             exit_error(msg)
 
         try:
@@ -278,15 +278,13 @@ def parse_shifts(
                       i got {stereo_specificty_code} at line {i + 1}"""
             exit_error(msg)
 
-        seq_key = chain_code, residue_number
+        residue_name = get_residue_name_from_lookup(
+            chain_code, residue_code, chain_seqid_to_type
+        )
 
-        residue_name = chain_seqid_to_type.setdefault(seq_key, UNUSED).upper()
-
-        if (
-            residue_number != UNUSED and chain_code != UNUSED
-        ) and residue_name == UNUSED:
+        if (residue_code != UNUSED and chain_code != UNUSED) and residue_name == UNUSED:
             msg = f"""\
-            [nmrview shifts] residue not defined for chain {chain_code} residue {residue_number}
+            residue not defined for chain {chain_code} residue {residue_code}
             line number {i+1}
             line was |{line}|
             in file {file_name}
@@ -294,9 +292,7 @@ def parse_shifts(
             msg = dedent(msg)
             exit_error(msg)
 
-        atom = AtomLabel(
-            SequenceResidue(chain_code, residue_number, residue_name), atom
-        )
+        atom = AtomLabel(SequenceResidue(chain_code, residue_code, residue_name), atom)
         shift = ShiftData(atom, shift)
         shifts.append(shift)
 
